@@ -23,7 +23,6 @@
 #endif
 
 #include "ephy-embed-shell.h"
-#include "ephy-frecent-store.h"
 #include "ephy-history-types.h"
 #include "ephy-web-view.h"
 
@@ -50,9 +49,6 @@ G_BEGIN_DECLS
 void                       ephy_web_view_set_visit_type           (EphyWebView *view, 
                                                                    EphyHistoryPageVisitType visit_type);
 EphyHistoryPageVisitType   ephy_web_view_get_visit_type           (EphyWebView *view);
-void                       ephy_web_view_set_loading_title        (EphyWebView               *view,
-                                                                   const char                *title,
-                                                                   gboolean                   is_address);
 void                       ephy_web_view_popups_manager_reset     (EphyWebView               *view);
 void                       ephy_web_view_save                     (EphyWebView               *view,
                                                                    const char                *uri);
@@ -61,11 +57,6 @@ void                       ephy_web_view_load_homepage            (EphyWebView
 char *                     ephy_web_view_create_web_application   (EphyWebView               *view,
                                                                    const char                *title,
                                                                    GdkPixbuf                 *icon);
-char*                      ephy_web_view_normalize_or_autosearch_url (EphyWebView            *view,
-                                                                      const char             *url);
-
-EphyFrecentStore          *ephy_embed_shell_get_frecent_store      (EphyEmbedShell *shell);
-
 G_END_DECLS
 
 #endif
