@@ -218,7 +218,8 @@ create_url_from_statement (EphySQLiteStatement *statement)
   url->id = ephy_sqlite_statement_get_column_as_int (statement, 0);
   url->host = ephy_history_host_new (NULL, NULL, 0, 1.0);
   url->hidden = ephy_sqlite_statement_get_column_as_int (statement, 6);
-  url->host->id = ephy_sqlite_statement_get_column_as_int (statement, 7);
+  url->thumbnail_time = ephy_sqlite_statement_get_column_as_int (statement, 7);
+  url->host->id = ephy_sqlite_statement_get_column_as_int (statement, 8);
 
   return url;
 }
@@ -241,6 +242,7 @@ ephy_history_service_find_url_rows (EphyHistoryService *self, EphyHistoryQuery *
       "urls.typed_count, "
       "urls.last_visit_time, "
       "urls.hidden_from_overview, "
+      "urls.thumbnail_update_time, "
       "urls.host "
     "FROM "
       "urls ";
@@ -274,12 +276,30 @@ ephy_history_service_find_url_rows (EphyHistoryService *self, EphyHistoryQuery *
   statement_str = g_string_append (statement_str, "1 ");
 
   switch (query->sort_type) {
-  case EPHY_HISTORY_SORT_MV:
+  case EPHY_HISTORY_SORT_MOST_VISITED:
     statement_str = g_string_append (statement_str, "ORDER BY urls.visit_count DESC ");
     break;
-  case EPHY_HISTORY_SORT_LV:
+  case EPHY_HISTORY_SORT_LEAST_VISITED:
     statement_str = g_string_append (statement_str, "ORDER BY urls.visit_count ");
     break;
+  case EPHY_HISTORY_SORT_MOST_RECENTLY_VISITED:
+    statement_str = g_string_append (statement_str, "ORDER BY urls.last_visit_time DESC ");
+    break;
+  case EPHY_HISTORY_SORT_LEAST_RECENTLY_VISITED:
+    statement_str = g_string_append (statement_str, "ORDER BY urls.last_visit_time ");
+    break;
+  case EPHY_HISTORY_SORT_TITLE_ASCENDING:
+    statement_str = g_string_append (statement_str, "ORDER BY LOWER(urls.title) ");
+    break;
+  case EPHY_HISTORY_SORT_TITLE_DESCENDING:
+    statement_str = g_string_append (statement_str, "ORDER BY LOWER(urls.title) DESC ");
+    break;
+  case EPHY_HISTORY_SORT_URL_ASCENDING:
+    statement_str = g_string_append (statement_str, "ORDER BY LOWER(urls.url) ");
+    break;
+  case EPHY_HISTORY_SORT_URL_DESCENDING:
+    statement_str = g_string_append (statement_str, "ORDER BY LOWER(urls.url) DESC ");
+    break;
   default:
     g_warning ("We don't support this sorting method yet.");
   }
@@ -331,7 +351,7 @@ ephy_history_service_find_url_rows (EphyHistoryService *self, EphyHistoryQuery *
       g_free (string);
       return NULL;
     }
-    if (ephy_sqlite_statement_bind_string (statement, i++, string, &error) == FALSE) {
+    if (ephy_sqlite_statement_bind_string (statement, i++, string + 2, &error) == FALSE) {
       g_error ("Could not build urls table query statement: %s", error->message);
       g_error_free (error);
       g_object_unref (statement);
